#pragma once

#include "fastfetch.h"

const char* ffNetifGetDefaultRouteIfName();
uint32_t ffNetifGetDefaultRouteIfIndex();
